{ config, pkgs, lib, ... }: {

  imports = [

    <system/desktop>
    ./hardware-configuration.nix

    ./packages.nix
    ./syncthing.nix
    ./tinc.nix

    #./wifi-access-point.nix
    #./wireshark.nix

  ];

  networking.hostName = "sterni";

  system.custom.wifi.interfaces = [ "wlp3s0" ];

  security.wrappers = {
    pmount.source = "${pkgs.pmount}/bin/pmount";
    pumount.source = "${pkgs.pmount}/bin/pumount";
  };

  # keybase
  services.keybase.enable = false;
  services.kbfs.enable = false;

  programs.custom.steam.enable = false;
  programs.custom.video.enable = false;

  services.printing.enable = true;

  # fonts
  # -----
  programs.custom.urxvt.fontSize = 12;
  programs.custom.xterm.fontSize = 12;
  system.custom.fonts.dpi = 100;

  virtualisation = {
    docker.enable = false;

    virtualbox = {
      host.enable = false;
      guest.x11 = false;
      guest.enable = false;
    };
  };

  configuration.desktop = {
    width = 1366;
    height = 768;
  };

  custom.samba-share = {
    enable = false;
    folders = {
      #public = "/home/palo/movies";
      share = "/home/share";
      #syncthing = "/mnt/syncthing";
      #movies = "/mnt/syncthing/movies";
      #series = "/mnt/syncthing/series";
    };
  };

  # enable this to use sidequest
  programs.adb.enable = true;
  users.users.mainUser.extraGroups = [ "adbusers" ];

}

